Objectstore Rest API — Rucio 1.2 documentation

# Objectstore Rest API

Overview

Resource | Operation | Description
--- | --- | ---
ObjectStore | POST /objectstores/(rse)/(operation) | get signed urls.
ObjectStoreGet | GET /objectstores/(url)/(rse)/(operation) | get signed url.
ObjectStoreInfo | POST /objectstores/(rse) | Get files metadata at a given RSE.
ObjectStoreRename | POST /objectstores/(rse) | Rename object.

Details

`GET` `/objectstores/`(url)`/`(rse)`/`(operation)

  Pass a url and return the signed url.

  Parameters: | url – A URL string. rse – RSE name. operation – the request operation (default: ‘read’).
  Status Codes: | 200 OK – OK. 401 Unauthorized – Invalid Auth Token. 500 Internal Server Error – Internal Error.
  Returns: | the signed URL.

  get redirect URL.

`POST` `/objectstores/`(rse)`/`(operation)

  Get URLs for files at a given RSE.

  Parameters: | rse – RSE name. operation – the request operation (default: ‘read’).
  Request JSON Object:
  | urls (string) – A list of URL strings.
  Response Headers:
  | Content-Type – application/json
  Status Codes: | 200 OK – OK. 400 Bad Request – Cannot decode json parameter list. 401 Unauthorized – Invalid Auth Token. 500 Internal Server Error – Internal Error.
  Returns: | Dictionary of Signed URLs.

`POST` `/objectstores/`(rse)

  Pass list of urls and return their metadata.

  Parameters: | rse – RSE name.
  Request JSON Object:
  | urls (string) – A list of URL string.
  Response Headers:
  | Content-Type – application/json
  Status Codes: | 200 OK – OK. 400 Bad Request – Cannot decode json parameter list. 401 Unauthorized – Invalid Auth Token. 500 Internal Server Error – Internal Error.
  Returns: | Dictonary of metadata.

`POST` `/objectstores/`(rse)

  Rename object.

  Parameters: | rse – the RSE name.
  Request JSON Object:
  | url (string) – the URL string. new_url (string) – the new URL string. urls (string) – A list of URL string.
  Response Headers:
  | Content-Type – application/json
  Status Codes: | 200 OK – OK. 400 Bad Request – Cannot decode json parameter list. 401 Unauthorized – Invalid Auth Token. 500 Internal Server Error – Internal Error.